#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
from setuptools import setup, find_packages

packages = []

setup(
    name='esyslog-ce',
    version='1.0.1',
    author='t.feng',
    author_email='fengtao40@huawei.com',
    packages=find_packages()
)
